# {{ cookiecutter.project_name }}

## How to start

1. generate project using `nb create` .
2. writing your plugins under `{{ cookiecutter.source_dir }}/plugins` folder.
3. run your bot using `nb run` .
